pytransport Documentation
=========================

pytransport is a set of classes and functions to load MADX output as well as prepare
Transport models. The package overall functions as a holder for any code required to
load and manipulate Transport output data.

.. toctree::
   :maxdepth: 2

   licence
   authorship
   installation
   converting
   moduledocs


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
